{% extends "admin/base_site.html" %}

<!-- LOADING -->
{% load i18n fb_tags fb_versions admin_static %}
{% load url from future %}

<!-- STYLESHEETS -->
{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />
    <link rel="stylesheet" type="text/css" href="{{ settings_var.URL_FILEBROWSER_MEDIA }}css/filebrowser.css" />
{% endblock %}

<!-- JAVASCRIPTS -->
{% block extrahead %}
    {{ block.super }}
    {{ media }}
{% endblock %}

<!-- COLTYPE/BODYCLASS -->
{% block bodyclass %}change-form filebrowser{% if query.pop %} popup{% endif %}{% endblock %}

<!-- BREADCRBUMBS -->
{% block breadcrumbs %}{% include "filebrowser/include/breadcrumbs.html" %}{% endblock %}

<!-- CONTENT -->
{% block content %}
<div id="content-main">
    <form>
        <fieldset class="module collapse open">
            <h2>{% blocktrans with fileobject.filename as escaped_object %}Are you sure you want to delete "{{ escaped_object }}"? All of the following items will be deleted:{% endblocktrans %}</h2>
            <div class="form-row">
                <div>
                    {{ fileobject.filename }}
                </div>
            </div>
            {% if filelisting %}
                <div class="form-row">
                    {% for item in filelisting %}
                        {{ item.path_relative_directory }}
                    {% endfor %}
                </div>
            {% endif %}
            {% if additional_files %}
                <div class="form-row">
                    {% blocktrans with additional_files as escaped_object %}... and {{ escaped_object }} more Files.{% endblocktrans %}
                </div>
            {% endif %}
        </fieldset>
        <div class="submit-row">
            <p class="deletelink-box">
                <a href="{% url 'filebrowser:fb_detail' %}{% query_string %}" class="deletelink">{% trans "Cancel" %}</a>
            </p>
            <a href="{% url 'filebrowser:fb_delete' %}{% query_string %}" class="button default">{% trans "Yes, I'm sure" %}</a>
        </div>
    </form>
</div>
{% endblock %}
