/*  Filebrowser Table
------------------------------------------------------------------------------------------------------ */

.filebrowser table {
    font-size: 11px;
}

.filebrowser thead th.sorted a {
    padding-right: 13px;
}

.filebrowser thead th.filename {
    min-width: 160px;
}

.filebrowser td {
    padding: 9px 10px 6px 10px !important;
}

.filebrowser td.fb_thumbnail {
    line-height: 11px;
}

/*  Filebrowser Buttons & Links
------------------------------------------------------------------------------------------------------ */

span.fb_type {
    display: inline-block;
    margin: 0 0;
    padding: 1px 0;
    color: #999;
    font-size: 11px;
    font-weight: bold;
    font-style: italic;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}

spanspan.fb_type.folder {
    color: #666;
    font-weight: bold;
}

/*  Filebrowser View-Link (contains thumbnail) & Select-Link......................................... */

a.fb_viewlink,
button.fb_selectlink {
    position: relative;
    float: left;
    top: -4px !important;
    margin-bottom: -5px !important;
}

button.fb_selectlink {
    padding-top: 3px;
    padding-bottom: 4px;
    height: 24px;
    font-size: 11px;
}

@media screen and (-webkit-min-device-pixel-ratio: 0) {
    button.fb_selectlink {
        padding-top: 4px;
    }
}

/*  Filebrowser Pulldown Actions
------------------------------------------------------------------------------------------------------ */

.pulldown-versions-container {
    position: relative;
    float: left;
}

.pulldown-versions-handler {
    position: relative;
    display: block;
    top: -4px;
    margin-left: 2px;
    width: 24px;
    height: 24px;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
}

.pulldown-versions-handler:link, .pulldown-versions-handler:visited {
    background: #309bbf url('../img/icon-pulldown-versions.png') 50% 10px no-repeat scroll;
    background: url('../img/icon-pulldown-versions.png') 50% 10px no-repeat scroll, -moz-linear-gradient(top, #33a6cc, #309bbf);
    background: url('../img/icon-pulldown-versions.png') 50% 10px no-repeat scroll, -webkit-gradient(linear, left top, left bottom, from(#33a6cc), to(#309bbf));
}

.pulldown-versions-handler:hover, .pulldown-versions-handler:active {
    background: #666 url('../img/icon-pulldown-versions-hover.png') 50% 10px no-repeat scroll;
    background: url('../img/icon-pulldown-versions-hover.png') 50% 10px no-repeat scroll, -moz-linear-gradient(top, #555, #444);
    background: url('../img/icon-pulldown-versions-hover.png') 50% 10px no-repeat scroll, -webkit-gradient(linear, left top, left bottom, from(#555), to(#444));
}

.open .pulldown-versions-handler {
    background: #666 url('../img/icon-pulldown-versions-active.png') 50% 9px no-repeat scroll;
    background: url('../img/icon-pulldown-versions-active.png') 50% 9px no-repeat scroll, -moz-linear-gradient(top, #555, #444);
    background: url('../img/icon-pulldown-versions-active.png') 50% 9px no-repeat scroll, -webkit-gradient(linear, left top, left bottom, from(#555), to(#444));
}

ul.pulldown-versions {
    display: none;
}

.open ul.pulldown-versions {
    display: block;
    position: absolute;
    z-index: 1000;
    margin: -2px 0 0 2px;
    padding: 0;
    border-radius: 5px;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    background: #eee;
    background: #309bbf;
    box-shadow: 0 0 50px #333;
    -moz-box-shadow: 0 0 50px #333;
    -webkit-box-shadow: 0 0 50px #333;
    list-style: none;
}

ul.pulldown-versions li {
    border-top: 1px solid #3da8cc;
    border-bottom: 1px solid #2987a6;
    list-style: none;
}

ul.pulldown-versions li:first-child {
    border-top: 0;
}

ul.pulldown-versions li:last-child {
    border-bottom: 0;
}

ul.pulldown-versions a {
    display: block;
    padding: 5px 30px 5px 10px;
    font-weight: bold;
    white-space: nowrap;
}

ul.pulldown-versions li:first-child a {
    border-top-left-radius: 5px;
    -moz-border-radius-topleft: 5px;
    -webkit-border-top-left-radius: 5px;
    border-top-right-radius: 5px;
    -moz-border-radius-topright: 5px;
    -webkit-border-top-right-radius: 5px;
}

ul.pulldown-versions li.last a {
    border-bottom-left-radius: 5px;
    -moz-border-radius-bottomleft: 5px;
    -webkit-border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px;
    -moz-border-radius-bottomright: 5px;
    -webkit-border-bottom-right-radius: 5px;
}

ul.pulldown-versions a:link, ul.pulldown-versions a:visited {
    color: #fff;
    background: #309bbf;
}

ul.pulldown-versions a:hover, ul.pulldown-versions a:active {
    color: #fff;
    background: #444;
}

/* Upload button
------------------------------------------------------------------------------------------------------ */
.qq-upload-button {
    background: #309bbf; /* Old browsers */
    background: -moz-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #36b0d9), color-stop(100%, #309bbf)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#36b0d9', endColorstr='#309bbf', GradientType=0); /* IE6-9 */
    background: linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* W3C */

    border: 1px solid #2987a6;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;

    padding: 6px;
    font: normal 13px/1 Arial, sans-serif;
    color: white;
    text-transform: uppercase;
    text-align: center;
    width: 140px;
}

.qq-upload-button:hover {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #444444), color-stop(100%, #333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%, #333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%, #333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%, #333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#444444', endColorstr='#333333', GradientType=0); /* IE6-9 */
    background: linear-gradient(top, #444444 0%, #333333 100%); /* W3C */

    border: 1px solid #333;
}

.qq-upload-list {
    clear: both;
    width: 350px;
}

.qq-upload-list li {
    font: 12px Arial, sans-serif;
    padding: 6px 0;
    width: 350px;
    border-bottom: 1px solid #e0e0e0;
}

.qq-upload-list li + li {
    border-top: 1px solid #fff;
}

.qq-upload-list li:last-child {
    padding-bottom: 0;
    border-bottom: 0;
}

span.qq-upload-file {
    font-weight: bold;
}

.qq-upload-failed-text {
    display: none;
}

.qq-upload-fail .qq-upload-failed-text {
    display: inline;
    margin-left: 10px;
    color: #bf3030;
    font-weight: bold;
}

.qq-upload-cancel {
    float: right;
    margin: 0 -2px 0 0;
    text-indent: -10000px;
    width: 16px;
    height: 16px;
    background: url('../img/cancel.png') top left no-repeat;
    cursor: pointer;
}

.qq-upload-cancel:hover {
    background: url('../img/cancel_hover.png') top left no-repeat;
}

.qq-upload-size {
    font-size: 11px;
    margin-left: 10px;
}

.progress-bar {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;

    background-color: #fff;
    border: 1px solid #999;
    height: 6px;
    width: 348px;
    margin: 4px 0 2px;
}

.progress-bar .content {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #444444), color-stop(100%, #333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%, #333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%, #333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%, #333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#444444', endColorstr='#333333', GradientType=0); /* IE6-9 */
    background: linear-gradient(top, #444444 0%, #333333 100%); /* W3C */

    height: 6px;
    width: 0%;
}

span.fb_type {
    background: url(../img/filebrowser_type_.gif) top left no-repeat;
    color: transparent;
}
span.fb_type.audio {
    background: url(../img/filebrowser_type_audio.gif) top left no-repeat;
    color: transparent;
}

span.fb_type.code {
    background: url(../img/filebrowser_type_code.gif) top left no-repeat;
    color: transparent;
}

span.fb_type.document {
    background: url(../img/filebrowser_type_document.gif) top left no-repeat;
    color: transparent;
}

span.fb_type.folder {
    background: url(../img/filebrowser_type_folder.gif) top left no-repeat;
    color: transparent;
}

span.fb_type.image {
    background: url(../img/filebrowser_type_image.gif) top left no-repeat;
    color: transparent;
}

span.fb_type.video {
    background: url(../img/filebrowser_type_video.gif) top left no-repeat;
    color: transparent;
}